==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/so-SO/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Isticmaalahaan wuu soo gali karaa',
    'activated_disabled_help_text' => 'Ma beddeli kartid heerka hawlgelinta akoonkaaga.',
    'assets_user'       => 'Hantida loo qoondeeyay :name',
    'bulk_update_warn'	=> 'Waxaad ku dhowdahay inaad wax ka beddesho sifooyinka isticmaalayaasha :user_count Fadlan ogow inaadan bedeli karin sifooyinkaaga isticmaale adigoo isticmaalaya foomkan, oo waa inaad si gaar ah wax uga beddesho isticmaalahaaga.',
    'bulk_update_help'	=> 'Foomkan wuxuu kuu ogolaanayaa inaad hal mar cusbooneysiiso isticmaaleyaal badan. Kaliya buuxi meelaha aad u baahan tahay inaad bedesho. Goob kasta oo bannaan ayaa ahaan doonta mid aan isbeddelin.',
    'current_assets'    => 'Hantida hadda la hubiyay isticmaalahan',
    'clone'             => 'Isticmaale Clone',
    'contact_user'      => 'La xidhiidh :name',
    'edit'              => 'Wax ka beddel Isticmaalaha',
    'filetype_info'     => 'Noocyada faylalka la oggol yahay waa png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, iyo rar.',
    'history_user'      => 'Taariikhda :name',
    'info'				=> 'Xog',
    'restore_user'		=> 'Riix halkan si aad u soo celiso.',
    'last_login'        => 'Gelidii u dambaysay',
    'ldap_config_text'  => 'Dejinta qaabeynta LDAP waxaa laga heli karaa Maamulka> Dejinta. Goobta (ikhtiyaarka) ee la doortay ayaa loo dejin doonaa dhammaan isticmaalayaasha la soo dhoofiyo.',
    'print_assigned'    => 'Daabac Dhammaan Ku-meel-gaadhka ah',
    'email_assigned'    => 'Liistada iimaylka ee Dhammaan la qoondeeyay',
    'user_notified'     => 'Isticmaalaha waxaa loo soo diray iimayl liiska alaabta hadda loo qoondeeyay.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Ku dar isticmaalahaan marka si toos ah loo qoondeeyo shatiyada xaqa u leh',
    'auto_assign_help'  => 'Ka bood isticmaalehan si otomaatig ah loogu diri lahaa shatiyada',
    'software_user'     => 'Software-ka la hubiyay :name',
    'send_email_help'   => 'Waa inaad siisaa ciwaanka iimaylka isticmaalahan si uu ugu soo diro aqoonsiyo. Aqoonsiga iimaylka waxaa lagu samayn karaa oo kaliya abuurista isticmaale. Erayada sirta ah waxa lagu kaydiyaa hash hal dhinac ah lamana soo saari karo marka la kaydiyo.',
    'view_user'         => 'Eeg isticmaale :name',
    'usercsv'           => 'Faylka CSV',
    'two_factor_admin_optin_help' => 'Dejinta maamulkaada hadda waxay ogolaadaan dhaqangelinta xulashada xaqiijinta laba arrimood.  ',
    'two_factor_enrolled' => '2FA Aalad wuu diiwaan gashan yahay ',
    'two_factor_active'   => '2FA firfircoon ',
    'user_deactivated'  => 'Isticmaaluhu ma soo gali karo',
    'user_activated'  => 'Isticmaaluhu wuu soo gali karaa',
    'activation_status_warning' => 'Ha bedelin heerka hawlgelinta',
    'group_memberships_helpblock' => 'Kaliya superadmins ayaa wax ka beddeli kara xubinnimada kooxda.',
    'superadmin_permission_warning' => 'Kaliya superadmins ayaa siin kara isticmaale superadmin gelitaanka.',
    'admin_permission_warning' => 'Kaliya isticmaalayaasha leh xuquuqda admins ama ka weyn ayaa siin kara marin u helka isticmaalaha.',
    'remove_group_memberships' => 'Ka saar Xubinnimada Kooxda',
    'warning_deletion_information' => 'Waxaad ku dhowdahay inaad iska hubiso DHAMMAAN walxaha :count isticmaalayaasha hoos ku taxan. Magacyada maamulka sare waxa lagu iftiimiyay casaan.',
    'update_user_assets_status' => 'Cusbooneysii dhammaan hantida isticmaalayaashan heerkan',
    'checkin_user_properties' => 'Hubi dhammaan guryaha la xidhiidha isticmaalayaashan',
    'remote_label'   => 'Kani waa isticmaale fog',
    'remote'   => 'Fogfog',
    'remote_help' => 'Tani waxay noqon kartaa mid faa\'iido leh haddii aad u baahan tahay inaad shaandhayso isticmaalayaasha fogfog ee aan weligood ama dhif ah soo gelin goobahaaga jireed.',
    'not_remote_label' => 'Kani maaha isticmaale fog',
    'vip_label' => 'Isticmaalaha VIP',
    'vip_help' => 'Tani waxay noqon kartaa mid waxtar leh in lagu calaamadiyo dadka muhiimka ah ee org-gaaga haddii aad jeclaan lahayd inaad siyaalo gaar ah ugu qabato.',
    'create_user' => 'Abuur isticmaale',
    'create_user_page_explanation' => 'Tani waa macluumaadka akoontiga aad isticmaali doonto si aad u gasho goobta markii ugu horeysay.',
    'email_credentials' => 'Aqoonsiga iimaylka',
    'email_credentials_text' => 'Imaylkayga aqoonsigayga iimaylka sare ku yaal',
    'next_save_user' => 'Xiga: Keydi Isticmaalaha',
    'all_assigned_list_generation' => 'Lagu soo saaray:',
    'email_user_creds_on_create' => 'Imayl u dir isticmaalahan aqoonsigiisa?',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/so-SO/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Isticmaalahaan wuu soo gali karaa',
    'activated_disabled_help_text' => 'Ma beddeli kartid heerka hawlgelinta akoonkaaga.',
    'assets_user'       => 'Hantida loo qoondeeyay :name',
    'bulk_update_warn'	=> 'Waxaad ku dhowdahay inaad wax ka beddesho sifooyinka isticmaalayaasha :user_count Fadlan ogow inaadan bedeli karin sifooyinkaaga isticmaale adigoo isticmaalaya foomkan, oo waa inaad si gaar ah wax uga beddesho isticmaalahaaga.',
    'bulk_update_help'	=> 'Foomkan wuxuu kuu ogolaanayaa inaad hal mar cusbooneysiiso isticmaaleyaal badan. Kaliya buuxi meelaha aad u baahan tahay inaad bedesho. Goob kasta oo bannaan ayaa ahaan doonta mid aan isbeddelin.',
    'current_assets'    => 'Hantida hadda la hubiyay isticmaalahan',
    'clone'             => 'Isticmaale Clone',
    'contact_user'      => 'La xidhiidh :name',
    'edit'              => 'Wax ka beddel Isticmaalaha',
    'filetype_info'     => 'Noocyada faylalka la oggol yahay waa png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, iyo rar.',
    'history_user'      => 'Taariikhda :name',
    'info'				=> 'Xog',
    'restore_user'		=> 'Riix halkan si aad u soo celiso.',
    'last_login'        => 'Gelidii u dambaysay',
    'ldap_config_text'  => 'Dejinta qaabeynta LDAP waxaa laga heli karaa Maamulka> Dejinta. Goobta (ikhtiyaarka) ee la doortay ayaa loo dejin doonaa dhammaan isticmaalayaasha la soo dhoofiyo.',
    'print_assigned'    => 'Daabac Dhammaan Ku-meel-gaadhka ah',
    'email_assigned'    => 'Liistada iimaylka ee Dhammaan la qoondeeyay',
    'user_notified'     => 'Isticmaalaha waxaa loo soo diray iimayl liiska alaabta hadda loo qoondeeyay.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Ku dar isticmaalahaan marka si toos ah loo qoondeeyo shatiyada xaqa u leh',
    'auto_assign_help'  => 'Ka bood isticmaalehan si otomaatig ah loogu diri lahaa shatiyada',
    'software_user'     => 'Software-ka la hubiyay :name',
    'view_user'         => 'Eeg isticmaale :name',
    'usercsv'           => 'Faylka CSV',
    'two_factor_admin_optin_help' => 'Dejinta maamulkaada hadda waxay ogolaadaan dhaqangelinta xulashada xaqiijinta laba arrimood.  ',
    'two_factor_enrolled' => '2FA Aalad wuu diiwaan gashan yahay ',
    'two_factor_active'   => '2FA firfircoon ',
    'user_deactivated'  => 'Isticmaaluhu ma soo gali karo',
    'user_activated'  => 'Isticmaaluhu wuu soo gali karaa',
    'activation_status_warning' => 'Ha bedelin heerka hawlgelinta',
    'group_memberships_helpblock' => 'Kaliya superadmins ayaa wax ka beddeli kara xubinnimada kooxda.',
    'superadmin_permission_warning' => 'Kaliya superadmins ayaa siin kara isticmaale superadmin gelitaanka.',
    'admin_permission_warning' => 'Kaliya isticmaalayaasha leh xuquuqda admins ama ka weyn ayaa siin kara marin u helka isticmaalaha.',
    'remove_group_memberships' => 'Ka saar Xubinnimada Kooxda',
    'warning_deletion_information' => 'Waxaad ku dhowdahay inaad iska hubiso DHAMMAAN walxaha :count isticmaalayaasha hoos ku taxan. Magacyada maamulka sare waxa lagu iftiimiyay casaan.',
    'update_user_assets_status' => 'Cusbooneysii dhammaan hantida isticmaalayaashan heerkan',
    'checkin_user_properties' => 'Hubi dhammaan guryaha la xidhiidha isticmaalayaashan',
    'remote_label'   => 'Kani waa isticmaale fog',
    'remote'   => 'Fogfog',
    'remote_help' => 'Tani waxay noqon kartaa mid faa\'iido leh haddii aad u baahan tahay inaad shaandhayso isticmaalayaasha fogfog ee aan weligood ama dhif ah soo gelin goobahaaga jireed.',
    'not_remote_label' => 'Kani maaha isticmaale fog',
    'vip_label' => 'Isticmaalaha VIP',
    'vip_help' => 'Tani waxay noqon kartaa mid waxtar leh in lagu calaamadiyo dadka muhiimka ah ee org-gaaga haddii aad jeclaan lahayd inaad siyaalo gaar ah ugu qabato.',
    'create_user' => 'Abuur isticmaale',
    'create_user_page_explanation' => 'Tani waa macluumaadka akoontiga aad isticmaali doonto si aad u gasho goobta markii ugu horeysay.',
    'email_credentials' => 'Aqoonsiga iimaylka',
    'email_credentials_text' => 'Imaylkayga aqoonsigayga iimaylka sare ku yaal',
    'next_save_user' => 'Xiga: Keydi Isticmaalaha',
    'all_assigned_list_generation' => 'Lagu soo saaray:',
    'email_user_creds_on_create' => 'Imayl u dir isticmaalahan aqoonsigiisa?',
    'department_manager' => 'Department Manager',
];
